#
# spec file for package librsync
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   librsync2
Name:           librsync
Version:        2.3.4
Release:        1.6
Summary:        A Library for Generating Network Deltas
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/librsync/librsync
Source:         https://github.com/librsync/%{name}/archive/v%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(popt)
BuildRequires:  pkgconfig(zlib)

%description
librsync implements the "rsync" algorithm, which allows remote
differencing of binary files.  librsync computes a delta relative to a
file's checksum, so the two files need not both be present to generate
a delta.

%package -n %{lname}
Summary:        A Library for Generating Network Deltas
# O/P added 2011-11-26
Group:          System/Libraries
Obsoletes:      librsync < %{version}-%{release}
Provides:       librsync = %{version}-%{release}

%description -n %{lname}
librsync implements the "rsync" algorithm, which allows remote
differencing of binary files.  librsync computes a delta relative to a
file's checksum, so the two files need not both be present to generate
a delta.

%package devel
Summary:        Development files for librsync
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
librsync implements the "rsync" algorithm, which allows remote
differencing of binary files.  librsync computes a delta relative to a
file's checksum, so the two files need not both be present to generate
a delta.

%package -n rdiff
Summary:        Frontend to rsync's delta algorithm
Group:          Productivity/Archiving/Backup

%description -n rdiff
rdiff computes and applies signature-based file differences.

%prep
%setup -q

%build
%cmake \
  -DENABLE_COMPRESSION=ON
%cmake_build

%install
%cmake_install

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%{_libdir}/librsync.so.*
%license COPYING
%doc AUTHORS NEWS.md README.md THANKS TODO.md

%files devel
%{_libdir}/librsync.so
%{_mandir}/man3/*
%{_includedir}/*.h

%files -n rdiff
%{_bindir}/rdiff
%{_mandir}/man1/*

%changelog
* Sun Mar 19 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.4:
  * Update github actions and fix `iwyu` build target. Update
    `checkout` and `upload-artifact` to v3. Update `lint.yml`
    installed packages for fixed iwyu deps.
  * Fix `iwyu` build target to ignore `fileutil.c`
    and use neater clang output with noisy "note:" output
    removed.  Run `make iwyu-fix` to fix
    includes for `tests/rabinkarp_perf.c`.
  * Make delta directly process the input stream if it has enough
    data. Delta operations will only accumulate data into the
    internal scoop buffer if the input buffer is too small,
    otherwise it will process the input directly.
    This makes delta calculations 5%%~15%% faster by avoiding
    extra data copying.
  * Improve documentation so that Doxygen generates more complete
    documentation with diagrams, renders better, and is more
    navigable as markdown docs on GitHub.
  * Tidy rdiff integration test scripts. Made the filenames and
    shell arguments for test scripts consistent. (dbaarda,
  * Add better cmake build type configuration support. Added
    `BuildType.cmake` with better support for selecting the
    build type and making it default to Debug.
  * Remove obsolete unused tests. Removed some obsolete mdfour
    test data files and `check-rdiff` perl script.
  * Fix warning for later CMake versions. New CMake versions
    started complaining about the filename `Findlibb2.cmake` not
    matching the LIBB2 variables being used.
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 2.3.2:
  * Fix #214 heap corruption for too small kbloom. This could have crashed
  delta operations for very small files/signatures.
  * Fix #207 and add Travis Windows checks and improve compatibility. Turn on
  `-Wconversion -Wno-sign-conversion` warnings for clang.
  * Fix a bug so patch will now fail returning RS_CORRUPT on encountering a
  zero length copy command instead of hanging.
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- udpate to 2.3.1:
  * Improved cmake popt handling to find popt dependencies using PkgConfig.
  * Tidied internal code and improved tests for netint.[ch], tube.c, and
  hashtable.h.
  * Improved C99 compatibility. Add `-std=c99 -pedantic` to `CMAKE_C_FLAGS` for
  gcc and clang. Fix all C99 warnings by making all code C99 compliant. Tidy
  all CMake checks, `#cmakedefines`, and `#includes`. Fix 64bit support for
  mdfour checksums (texierp, dbaarda,
  * Usage clarified in rdiff (1) man page. (AaronM04,
  * Fix #176 hangs calculating deltas for files larger than 4GB.
  * Add RabinKarp rollsum support and make it the default. RabinKarp is a much
  better rolling hash, which reduces the risk of hash collision corruption
  and speeds up delta calculations. The rdiff cmd gets a new `-R
  (rollsum|rabinkarp)` argument with the default being `rabinkarp`, Use `-R
  rollsum` to generate backwards-compatible signatures. (dbaarda,
  https://github.com/librsync/librsync/issues/3)
  * Use single-byte literal commands for small inserts in deltas. This makes
  each small insert use 1 less byte in deltas. (dbaarda,
  https://github.com/librsync/librsync/issues/120)
  * Change rs_file_size() to report -1 instead of 0 for unknown file sizes
  * Add cmake BUILD_SHARED_LIBS option for static library support.
  * Fix compile errors and add .gitignore entries for MSVS 2019. Fixes
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.0:
- Remove no longer applicable patches:
  * blake2-config.patch
  * librsync-0.9.7-getopt.patch
  * librsync-0.9.7-strictalias.diff
  * librsync-exports.patch
  * librsync-man-example.diff
* Mon Mar 23 2015 schwab@linux-m68k.org
- blake2-config.patch: add missing <config.h>
* Mon Feb 16 2015 tchvatal@suse.com
- Version bump to 1.0.0 fixes bnc#900914 CVE-2014-8242:
  * Various build fixes, thanks Timothy Gu.
  * Improved rdiff man page from Debian.
  * Fixed bug #1110812 'internal error: job made no progress'; on large
    files.
  * Moved hosting to https://github.com/librsync/librsync/
  * Travis-CI.org integration test at https://travis-ci.org/librsync/librsync/
  * Remove bundled copy of popt; it must be installed separately.
- Refreshed patches:
  * librsync-man-example.diff
- Removed patches:
  * librsync-noexecstack-nestedfunc.patch
  * librsync-serial-tests.patch
  * librsync-logn-sumset.patch
  * librsync-logn-search.patch
- Removed patches due to promoting bugs:
  * librsync-0.9.7-largefiles.patch - currently in progress on:
    https://github.com/librsync/librsync/pull/14
* Sat Sep 13 2014 crrodriguez@opensuse.org
- Library ends compiled with executable stack, something we really
  do not want around.. it turns out a nested function causes gcc
  to emit trampolines. fix that (librsync-noexecstack-nestedfunc.patch)
- Only export the public api, all symbols prefixed with "rs_"
  (librsync-exports.patch)
* Wed May 14 2014 tchvatal@suse.com
- Remove accidentaly added file.
* Tue May 13 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Add patch librsync-0.9.7-getopt.patch fixing debian bug#435894
  * makes rdiff avare of -i and -z getopt options
* Thu May  2 2013 crrodriguez@opensuse.org
- librsync-serial-tests.patch fix build with new automake
* Fri Mar 15 2013 hpj@urpla.net
- apply librsync-logn-search.patch, librsync-logn-sumset.patch
  librsync-man-example.diff
- refresh all patches
- enable tests
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Employ shlib packaging
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Sep  2 2007 crrodriguez@suse.de
- library was unable to handle files larger than 4GB properly (librsync-0.9.7-largefiles.patch)
- fix build dependencies
* Sat Aug 25 2007 crrodriguez@suse.de
- spec cleanup
- stop using bundled popt library, use system one
- enable shared library
- disable static library
- remove libtool archive
* Sat Mar 24 2007 rguenther@suse.de
- add libbz2-devel and zlib-devel BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Thu Apr 14 2005 cthiel@suse.de
- update to 0.9.7
* Fri Feb  6 2004 garloff@suse.de
- Fix strict aliasing issues.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sun Aug 17 2003 garloff@suse.de
- Reenable installation of rdiff tool.
- Update to 0.9.6:
  * Large file support fixes.
  * [v]snprintf or _[v]snprintf autoconf replacement function fix.
  * Changed installed include file from rsync.h to librsync.h.
  * Rollsum bugfix that produces much smaller deltas.
  * Memory leaks bugfix patches.
  * mdfour bigendian and >512M bugfix, plus optimisations patch.
  * autoconf/automake updates and cleanups for autoconf 2.53.
* Fri Aug 16 2002 ro@suse.de
- removed empty post/postun scripts (#17922)
* Tue Jan 29 2002 schwab@suse.de
- Build with -fPIC so that it can be included in a shared library.
- Fix unaligned accesses.
* Mon Jan 28 2002 garloff@suse.de
- Fix building for s390x by using %%{_libdir}
* Fri Jan 18 2002 garloff@suse.de
- Update to 0.9.5 (moved from samba.org to sourceforge apparently)
* Thu Jan 17 2002 garloff@suse.de
- Initial creation of package (0.9.3)
